@@ -273,7 +273,7 @@ QStringList RedditSession::getCategories()
     cats << m_myreddits;
 
     cats << "programming" << "pics" << "technology" << "funny"
-         << "news" << "comics" << "python" << "wtf" << "gaming" <<
+         << "news" << "comics" << "Python" << "wtf" << "gaming" <<
          "IAmA" << "maemo" << "meego" << "science" << "bestof" << "gadgets" <<
          "music" << "hardware" << "worldnews" << "linux" << "offbeat" << "sports";
 
